@@ -5,14 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cdk-assets-schema",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "cdk-assets-schema@1.63.0.jsii.tgz",
+    "cdk-assets-schema@1.64.0.jsii.tgz",
 )
 
 __all__ = [
